@@ -1,10 +1,11 @@
 from django.db.models import Q
 from django_scopes import scopes_disabled
-from pretix.base.models import Order, OrderPosition, TeamAPIToken
-from rest_framework import exceptions, viewsets
+from pretix.base.models import Order, OrderPosition
+from rest_framework import viewsets
 from rest_framework.decorators import action
 from rest_framework.response import Response
 
+from .permissions import check_permission
 from .serializers import (
     AttendeeHasTicketBodySerializer,
     AttendeeTicketBodySerializer,
@@ -12,15 +13,6 @@ from .serializers import (
 )
 
 
-def check_permission(request, permission):
-    # Only allow Team API tokens to call this API.
-    perm_holder = request.auth if isinstance(request.auth, TeamAPIToken) else None
-    if not perm_holder or not perm_holder.has_event_permission(
-        request.event.organizer, request.event, permission
-    ):
-        raise exceptions.PermissionDenied()
-
-
 class TicketsViewSet(viewsets.ViewSet):
     # Disable scoping because we want to allow cross-organization checking
     # This allows us to do stuff like, you can attend PyCon Italia 2022
